<?php
// $Id: wistia.inc,v 1.1 2011/02/06 00:14:35 evandonovan Exp $

/**
 * @file
 * media_wistia/includes/providers/wistia.inc
 * Provide support for the Wistia provider to the emfield.module.
 */

/**
 * Implementation of hook emvideo_PROVIDER_info.
 * This returns information relevant to a specific 3rd party video provider.
 *
 * @TODO: add additional capabilities indicated by the Data API.
 *
 * @return
 *   an array of strings requested by various admin and other forms
 *   'name' => the translated name of the provider
 *   'url' => the url to the main page for the provider
 *   'settings_description' => a description of the provider that will be posted in the admin settings form
 *   'supported_features' => an array of rows describing the state of certain supported features by the provider.
 *      These will be rendered in a table, with the columns being 'Feature', 'Supported', 'Notes'.
 */
function emvideo_wistia_info() {
  $features = array(
    // array(t('Thumbnails'), t('Yes'), t('You may select the size of thumbnail to request from Wistia.')),
    // array(t('Full screen mode'), t('Yes'), t('You may customize the player to enable or disable full screen playback. Full screen mode is enabled by default.')),
    array(t('Duration'), t('Yes'), t("A video's duration can be displayed using view formatters.")),
  );
  return array(
    'provider' => 'wistia',
    'name' => t('Wistia'),
    'url' => MEDIA_WISTIA_MAIN_URL,
    'settings_description' => t('These settings specifically affect videos displayed from <a href="@provider" target="_blank">Wistia</a>. You can learn more about its <a href="@api" target="_blank">API</a> here. (All use of Wistia embeds requires an API key.)', array('@provider' => MEDIA_WISTIA_MAIN_URL, '@api' => MEDIA_WISTIA_API_INFO)),
    'supported_features' => $features,
  );
}

/**
 * Implementation of hook emvideo_PROVIDER_settings.
 * This returns a subform to be added to the emvideo_settings() admin settings page.
 * Note that a form field will already be provided, at $form['PROVIDER'] (such as $form['wistia'])
 * so if you want specific provider settings within that field, you can add the elements to it.
 */
function emvideo_wistia_settings() {
  module_load_include('inc', 'media_wistia', 'includes/media_wistia.admin');
  return media_wistia_admin_form();
}

/**
 * Implementation of hook emvideo_PROVIDER_extract.
 * This is called to extract the video ID from a pasted URL or embed code.
 *
 * @TODO: Test & tidy up the regexes for the embed and URL.
 * Note that the http://subdomain.wistia.com/medias/123456 URL only works for private videos
 * The fact that the embed code is required for public videos should be documented.
 *
 * @param $video_code
 *   an optional string with the pasted URL or embed code
 * @return
 *   either an array of regex expressions to be tested, or a string with the video code to be used
 *   if the hook tests the code itself, it should return either the string of the video code (if matched), or an empty array.
 *   otherwise, the calling function will handle testing the embed code against each regex string in the returned array.
 */
function emvideo_wistia_extract($video_code = '') {
  // http://wistia.com/medias/123456
  // http://subdomain.wistia.com/medias/123456
  // <object width="640" height="480" id="wistia_257382" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000">
  return array(
    '@id="wistia_[0-9]+"@i',
    '@wistia\.com/medias/[^\"\&\d]*([^\"\&]+)@i',
  );
}

/**
 * Implementation of hook emvideo_PROVIDER_embedded_link($video_code):
 * returns a link to view the video at the provider's site
 *  @param $video_code
 *    the string containing the video to watch
 *  @return
 *    a string containing the URL to view the video at the original provider's site
 */
function emvideo_wistia_embedded_link($video_code) {
  return media_wistia_video_url($video_code);
}

/**
 * Implementation of hook emvideo_PROVIDER_video.
 * This actually displays the full/normal-sized video we want, usually on the default page view.
 * It uses themes/media-wistia.tpl.php for rendering, defined in media_wistia.module.
 *
 *
 *  @param $video_code
 *    the video code for the video to embed
 *  @param $width
 *    the width to display the video
 *  @param $height
 *    the height to display the video
 *  @param $field
 *    the field info from the requesting node
 *  @param $item
 *    the actual content from the field
 *  @return
 *    the html of the embedded video
 */
function emvideo_wistia_video($video_code, $width, $height, $field, $item, $node, $autoplay, $options = array()) {
  $options['width'] = isset($options['width']) ? $options['width'] : $width;
  $options['height'] = isset($options['height']) ? $options['height'] : $height;
  $options['autoplay'] = isset($options['autoplay']) ? $options['autoplay'] : $autoplay;
  return theme('media_wistia', $video_code, $options);
}

/**
 * Implementation of hook emvideo_PROVIDER_preview.
 * This actually displays the preview-sized video we want, commonly for the teaser.
 * It uses themes/media-wistia.tpl.php for rendering, defined in media_wistia.module.
 *
 *  @param $video_code
 *    the video code for the video to embed
 *  @param $width
 *    the width to display the video
 *  @param $height
 *    the height to display the video
 *  @param $field
 *    the field info from the requesting node
 *  @param $item
 *    the actual content from the field
 *  @return
 *    the HTML of the embedded video
 */
function emvideo_wistia_preview($video_code, $width, $height, $field, $item, $node, $autoplay, $options = array()) {
  $options['width'] = isset($options['width']) ? $options['width'] : $width;
  $options['height'] = isset($options['height']) ? $options['height'] : $height;
  $options['autoplay'] = isset($options['autoplay']) ? $options['autoplay'] : $autoplay;
  return theme('media_wistia', $video_code, $options);
}


/**
 * Implementation of hook emvideo_PROVIDER_thumbnail.
 * returns the external url for a thumbnail of a specific video
 * TODO (aaron): make the args: ($video_code, $field, $item),
 * with $field/$item provided if we need it,
 * but otherwise simplifying things
 *
 *  @param $field
 *    the field of the requesting node
 *  @param $item
 *    the actual content of the field from the requesting node
 *  @return
 *    a URL pointing to the thumbnail
 */
function emvideo_wistia_thumbnail($field, $item, $formatter, $node, $width, $height) {
  return media_wistia_thumbnail_url($item['value']);
}

/**
 * Implementation of hook emvideo_PROVIDER_content_generate().
 * @TODO: remove this completely, if it is not necessary.
 */
/* function emvideo_wistia_content_generate() {
  return array(
    'http://example.wistia.com/medias/257382',
  );
} */

/**
 * Implementation of hook emvideo_PROVIDER_data_version().
 * Defined in includes/media_wistia.variables.inc.
 * Returns the Wistia Data API version.
 */
function emvideo_wistia_data_version() {
  return MEDIA_WISTIA_DATA_VERSION;
}

/**
 * Implementation of hook emvideo_PROVIDER_data().
 * Returns the data provided by the Wistia Data API.
 */
function emvideo_wistia_data($field, $item) {
  return media_wistia_data($item['value']);
}

/**
 * Implementation of hook emvideo_PROVIDER_duration($item)
 * Returns the duration of the video in seconds.
 *  @param $item
 *    The video item itself, which needs the $data array.
 *  @return
 *    The duration of the video in seconds.
 */
function emvideo_wistia_duration($item) {
  return media_wistia_duration($item['value']);
}
